#!/usr/bin/env node
'use strict';

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _package = require('../package');

var _package2 = _interopRequireDefault(_package);

var _index = require('./index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function parseCell(info) {
  const result = {};
  const arr = info.split(',');
  if (arr.length === 4) {
    result.mcc = arr[0];
    result.mnc = arr[1];
    result.lac = arr[2];
    result.cid = arr[3];
  }
  return result;
}

function parseArguments(data) {
  const result = {};
  data.split(',').forEach(x => {
    const pair = x.split(':');
    if (pair[0]) {
      result[pair[0].trim()] = pair[1].trim();
    }
  });
  return result;
}

function setup() {
  _commander2.default.description('Locate geolocation information based on Cell base station data').version(_package2.default.version).option('-c, --cell <cell>', 'Cell tower base station information in format "MCC,MNC,LAC,CID". "-c 460,0,4219,20925"', parseCell).option('-e, --engine <engine>', 'Geolocation service engine. {google, mozilla, opencellid, yandex, cellocation, gpsspg, haoservice, mylnikov}. Default: google', /^(google|mozilla|opencellid|yandex|cellocation|gpsspg|haoservice|mylnikov)$/i, 'google').option('-a, --arguments <arguments>', 'Arguments for geolocation engine. e.g. "key:XXX,oid:123".', parseArguments).option('-m, --map <map>', 'Map service. {google, bing, openstreetmap, google.cn, bing.cn, baidu}. Default: google', /^(google|bing|google\.cn|bing\.cn|openstreetmap|baidu)$/i).option('-v, --verbose', 'Verbose output.').on('--help', () => {
    console.log('  Examples:');
    console.log();
    console.log('    $ mobile-locator -a "key:XXX" -c 460,0,4219,20925');
    console.log('    $ mobile-locator -e cellocation -a "system:bd09" -m baidu -c 460,0,4219,20925');
    console.log();
  }).parse(process.argv);
}

function main() {
  if (_commander2.default.verbose) {
    console.log('Geolocation engine: %j', _commander2.default.engine);
    _commander2.default.arguments.verbose = true;
  }
  const engine = _index.locator.createEngine(_commander2.default.engine, _commander2.default.arguments);
  if (_commander2.default.cell) {
    if (_commander2.default.verbose) {
      console.log('Cell: %j', _commander2.default.cell);
    }
    engine.locate(_commander2.default.cell, (error, location) => {
      if (error) {
        console.error(error);
        _commander2.default.help();
        return;
      }

      if (_commander2.default.verbose || _commander2.default.map) {
        //  Verbose or need to show a map url
        console.log('Location: %j', location);
      } else {
        //  output pure JSON
        console.log(JSON.stringify(location));
      }

      if (_commander2.default.map) {
        const url = _index.map.format(_commander2.default.map, location);
        console.log(`Map url: ${ url }`);
      }
      return;
    });
  } else {
    console.error('Missing cell base station information.');
    _commander2.default.help();
  }
}

setup();
main();