'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Base {
  constructor(options) {
    if (options && options.verbose) {
      _request2.default.debug = true;
    }
  }
  getRequestSettings() {
    return {};
  }

  preprocessBody(body) {
    return body;
  }

  validate() {
    return true;
  }

  parseLocation() {
    return {};
  }

  parseError(body) {
    return body;
  }

  locate(cell, callback) {
    //  Send request
    (0, _request2.default)(this.getRequestSettings(cell), (error, response, body) => {
      if (error) {
        //  Callback with error
        if (_lodash2.default.isFunction(callback)) {
          callback(`Request Error: ${ JSON.stringify(error) }`, null);
        }
      } else {
        const b = this.preprocessBody(body);
        if (response.statusCode === 200) {
          if (!this.validate(b)) {
            //  Callback with error message
            if (_lodash2.default.isFunction(callback)) {
              callback(`Response Error: ${ JSON.stringify(this.parseError(b)) }`, null);
            }
          } else {
            //  Callback with location info
            if (_lodash2.default.isFunction(callback)) {
              callback(null, this.parseLocation(b));
            }
          }
        } else {
          //  Callback with HTTP Status Error Code
          if (_lodash2.default.isFunction(callback)) {
            const status = `${ response.statusCode }: ${ response.statusMessage }`;
            callback(`Response Error: ${ status } (${ JSON.stringify(this.parseError(b)) })`, null);
          }
        }
      }
    });
  }
}
exports.default = Base;