'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _base = require('./base');

var _base2 = _interopRequireDefault(_base);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const API = 'http://api.cellocation.com/cell/';

class Cellocation extends _base2.default {
  constructor(options) {
    super(options);
    if (options) {
      //  Coordinate System
      //  {'wgs84', 'gcj02', 'bd09'}
      this.system = options.system ? options.system : 'wgs84';
    }
  }

  getRequestSettings(cell) {
    return {
      uri: API,
      json: true,
      qs: {
        mcc: cell.mcc,
        mnc: cell.mnc,
        lac: cell.lac,
        ci: cell.cid,
        coord: this.system,
        output: 'json'
      }
    };
  }

  validate(body) {
    return body.errcode === 0;
  }

  parseLocation(body) {
    return {
      longitude: body.lon,
      latitude: body.lat,
      accuracy: body.radius,
      address: body.address
    };
  }

  parseError(body) {
    return _lodash2.default.has(body, 'error') ? body.error : body;
  }
}
exports.default = Cellocation;