'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _base = require('./base');

var _base2 = _interopRequireDefault(_base);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const API = 'http://api.gpsspg.com/bs/';

class GPSspg extends _base2.default {
  constructor(options) {
    super(options);
    if (options) {
      this.key = options.key;
      this.oid = options.oid;
      this.system = options.system;
    }
  }

  getRequestSettings(cell) {
    return {
      uri: API,
      qs: {
        oid: this.oid,
        type: '',
        mcc: cell.mcc,
        mnc: cell.mnc,
        a: cell.lac,
        b: cell.cid,
        //  0:WGS84; 1:Google Maps; 2:Baidu Maps; 3:QQ Maps; 4:MapBar
        to: this.system || 0,
        key: this.key,
        output: 'json'
      },
      json: true
    };
  }

  validate(body) {
    return !_lodash2.default.has(body, 'error') && body.status === '200';
  }

  parseLocation(body) {
    return {
      longitude: body.result.lng,
      latitude: body.result.lat,
      accuracy: body.result.radius,
      address: body.result.address
    };
  }

  parseError(body) {
    return _lodash2.default.has(body, 'status') ? body.status : body;
  }
}
exports.default = GPSspg;