'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _base = require('./base');

var _base2 = _interopRequireDefault(_base);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const API = 'http://api.lbs.yandex.net/geolocation';

class Yandex extends _base2.default {
  constructor(options) {
    super(options);
    if (options) {
      this.key = options.key;
    }
  }

  getRequestSettings(cell) {
    const json = {
      common: {
        version: '1.0',
        api_key: this.key
      },
      gsm_cells: [{
        countrycode: cell.mcc,
        operatorid: cell.mnc,
        lac: cell.lac,
        cellid: cell.cid
      }]
    };
    return {
      method: 'POST',
      uri: API,
      body: `json=${ JSON.stringify(json) }`
    };
  }

  preprocessBody(body) {
    return JSON.parse(body);
  }

  validate(body) {
    try {
      return !_lodash2.default.has(body, 'error') && body.position.type !== 'ip';
    } catch (e) {
      return false;
    }
  }

  parseLocation(body) {
    return {
      longitude: body.position.longitude,
      latitude: body.position.latitude,
      accuracy: body.position.precision
    };
  }

  parseError(body) {
    if (_lodash2.default.has(body, 'error')) {
      return `[${ body.error.code }] ${ body.error.text }`;
    }

    if (body.position.type === 'ip') {
      return 'Cell not found.';
    }

    return body;
  }
}
exports.default = Yandex;