'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.map = exports.locator = exports.LocatorManager = undefined;

var _googleGeolocation = require('./engines/google-geolocation');

var _googleGeolocation2 = _interopRequireDefault(_googleGeolocation);

var _mozillaGeolocation = require('./engines/mozilla-geolocation');

var _mozillaGeolocation2 = _interopRequireDefault(_mozillaGeolocation);

var _opencellid = require('./engines/opencellid');

var _opencellid2 = _interopRequireDefault(_opencellid);

var _yandex = require('./engines/yandex');

var _yandex2 = _interopRequireDefault(_yandex);

var _cellocation = require('./engines/cellocation');

var _cellocation2 = _interopRequireDefault(_cellocation);

var _gpsspg = require('./engines/gpsspg');

var _gpsspg2 = _interopRequireDefault(_gpsspg);

var _haoservice = require('./engines/haoservice');

var _haoservice2 = _interopRequireDefault(_haoservice);

var _mylnikov = require('./engines/mylnikov');

var _mylnikov2 = _interopRequireDefault(_mylnikov);

var _mapservice = require('./mapservice');

var _mapservice2 = _interopRequireDefault(_mapservice);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class LocatorManager {
  constructor() {
    this.engines = [];
    //  register existing services
    this.register('google', _googleGeolocation2.default);
    this.register('mozilla', _mozillaGeolocation2.default);
    this.register('opencellid', _opencellid2.default);
    this.register('yandex', _yandex2.default);
    this.register('cellocation', _cellocation2.default);
    this.register('gpsspg', _gpsspg2.default);
    this.register('haoservice', _haoservice2.default);
    this.register('mylnikov', _mylnikov2.default);
  }
  register(name, engine) {
    this.engines[name] = engine;
  }
  unregister(name) {
    delete this.engines[name];
  }
  createEngine(name, options) {
    if (this.engines[name]) {
      return new this.engines[name](options);
    }
    return null;
  }
}

exports.LocatorManager = LocatorManager;
const locator = exports.locator = new LocatorManager();
exports.default = locator;
const map = exports.map = new _mapservice2.default();